@@ -11,7 +11,7 @@ from jsonclasses.excs import UniqueConstraintException
 from jsonclasses.excs import DeletionDeniedException
 from inflection import underscore, camelize
 from .pymongo_object import PymongoObject
-from .query import BaseQuery, ExistQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
+from .query import BaseQuery, ExistQuery, IDSQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
 from .encoder import Encoder
 from .connection import Connection
 from .utils import ref_db_field_key
@@ -42,6 +42,13 @@ def pymongo_id(cls: type[T], id: str | ObjectId, *args, **kwargs: Any) -> IDQuer
         return IDQuery(cls=cls, id=id, matcher=kwargs)
 
 
+def pymongo_ids(cls: type[T], ids: list[str | ObjectId], *args, **kwargs: Any) -> IDSQuery[T]:
+    if len(args) > 0:
+        return IDSQuery(cls=cls, ids=ids, matcher=args[0])
+    else:
+        return IDSQuery(cls=cls, ids=ids, matcher=kwargs)
+
+
 def linked(cls: type[T], *args, **kwargs: Any) -> BaseQuery[T]:
     if len(args) > 0:
         return SingleQuery(cls=cls, filter=args[0])
@@ -221,6 +228,7 @@ def pymongofy(class_: type) -> PymongoObject:
     class_.find = classmethod(find)
     class_.one = classmethod(one)
     class_.id = classmethod(pymongo_id)
+    class_.ids = classmethod(pymongo_ids)
     class_.linked = classmethod(linked)
     class_.exist = classmethod(exist)
     class_.iterate = classmethod(iterate)
